@@ -1,4 +1,5 @@
-NF_VIDEO_PLAYER_LINK='http://213.108.4.28/video/player/'
+NF_VIDEO_PLAYER_LINK='https://213.108.4.28/video/player/'
+NF_NEW_SHEME_URL='http://62.113.105.179/api/canvas-draw/v1/canvas/render?id='
 
 
 
@@ -11,4 +12,7 @@ def create_player_link(to_nftv_id) -> str:
             a 13 digid video id of Nanofootball video server
             ex. 1669983631719
             """
-    return f'{NF_VIDEO_PLAYER_LINK}{to_nftv_id}'
\ No newline at end of file
+    return f'{NF_VIDEO_PLAYER_LINK}{to_nftv_id}'
+
+def scheme_url(sheme_id) -> str:
+    return f'{NF_NEW_SHEME_URL}{sheme_id}'
\ No newline at end of file
