@@ -1,8 +1,6 @@
 from nf_presentation.renderers.base_renderer import BaseRenderer
 from nf_presentation.data_classes import SingleExerciseInfo
-from nf_presentation.html_renderer import HTMLRenderer
-from nf_presentation.scheme_renderer import SchemeRenderer
-import nf_presentation.assets as assets
+from nf_presentation.builders import ParagraphBuilder
 
 from nf_presentation._settings import compact_layout as current_layout
 import nf_presentation.settings as base_settings
@@ -19,18 +17,24 @@ _default_description="""Описание:
 
 class RenderOptions:
     _media_fields=['video_1','video_2','animation_1','animation_2']
-    def __init__(self,raw_data):
-        self.raw_data=raw_data
+    _scheme_priority=['scheme_1','scheme_2']
+    def __init__(self,raw_data:dict):
+        self.raw_data:dict=raw_data
         self.check()
     @property
     def media_fields_to_render(self) -> list[str]:
         """returns a list of edia fields should be rendered to a pptx
         ['video_2','animation_1']"""
         return [field for field in self._media_fields if self.raw_data.get(field)]  # if checked as True
+    @property
+    def schemes_to_render(self):
+        return [scheme_name for scheme_name in self._scheme_priority if self.raw_data.get(scheme_name)]
     def check(self):
         #check if video or animation will be added to pptx
         if not any([self.raw_data.get(field) for field in self._media_fields]):
             logger.warn('(Render Options) no player links are marked to be added to pptx')
+        if not any(self.schemes_to_render):
+            logger.warn('(Render Options) no scheme links are marked to be added to pptx')
 
 
 
@@ -63,26 +67,52 @@ class CompactRenderer(BaseRenderer):
         else:
             left_rows=[(param,'') for param in additional_params]
 
+        if current_layout.CAPITALIZE_ADDITIONAL_DATA:
+            capitalized_rows=[]
+            for row in left_rows:
+                capitalized_rows.append((text.upper() for text in row))
+            left_rows=capitalized_rows
+
         left_table=slide.create_table().at(current_layout.LEFT_TABLE_POSITION).with_width(current_layout.LEFT_TABLE_WIDTH)
         left_table.append_row(exercise.title)
         left_table.append_empty_row()
         
         for row in left_rows:
            left_table.append_row(*row) 
-        # left_table.append_empty_row()
-        # left_table.append_row('ссылки')
-        # #maybe exercise info should return a tuples already
 
-        s=SchemeRenderer()
-        image_stream=s.to_stream(exercise.schemes[0])
-        self._open_streams.append(image_stream)
-        slide.create_image(image_stream).at(current_layout.SCHEME_POSITION).set_size(current_layout.SCHEME_WIDTH,None)
+        #schemes
+        scheme_added=False
+           
+        for scheme_name in self.render_options.schemes_to_render:
+            scheme=exercise.get_scheme_by_name(scheme_name)
+            if not scheme:
+                logger.warn(f'Cant add scheme "{scheme}" to slide, because it is not in the exercise data')
+                continue      
+
+            image_stream=scheme.to_stream()
+            if not image_stream:
+                logger.warn(f'cant add scheme "{scheme}" to slide, because its stream is None')
+                continue
+
+            self._open_streams.append(image_stream)
+            slide.create_image(image_stream).at(current_layout.SCHEME_POSITION).set_size(current_layout.SCHEME_WIDTH,None)
+
+            scheme_added=True
+            break
+        if not scheme_added:
+            logger.error('No scheme added to slide. ')
+            #TODO image fallback
 
         #add links
         links_added=False
-        slide.create_text('Ссылки:').at(current_layout.LINKS_TITLE_POSITION)
+        #links_table=slide.create_table().at(current_layout.LINKS_TABLE_POSITION).with_width(current_layout.LEFT_TABLE_WIDTH)
+        
 
-        link_position=current_layout.LINKS_AREA
+        ## TODO extract as media links
+        pb=ParagraphBuilder()
+        #link_position=current_layout.LINKS_AREA
+        video_counter=0
+        animation_counter=0
         for media_field in self.render_options.media_fields_to_render:
             media=exercise.get_media(media_field)
             if not media.exist:
@@ -92,17 +122,33 @@ class CompactRenderer(BaseRenderer):
 
             player_url=exercise.get_media(media_field).nftv_player
             is_animation='animation' in media_field
+            if is_animation:
+                animation_counter=animation_counter+1
+            else:
+                video_counter=video_counter+1
+            
+            
 
-            image_file=current_layout.LINKS_ANIMATION_ICON_FILENAME if is_animation else current_layout.LINKS_VIDEO_ICON_FILENAME
-            image_stream=assets.convert_to_png(filename=image_file)
-            self.track_stream(image_stream)
-            slide.create_image(image_file=image_stream).at(link_position).with_size(current_layout.LINKS_IMAGE_SIZE).with_href(player_url)
+            pb.append_link(
+                link_text=f"Анимация {animation_counter}" if is_animation else f"Видео {video_counter}",
+                href=player_url)
+            pb.append_text(' ')
 
-            x_delta,_=current_layout.LINKS_IMAGE_SIZE
-            x,y=link_position
-            link_position=(x+x_delta,y)
+            
+
+            #image_file=current_layout.LINKS_ANIMATION_ICON_FILENAME if is_animation else current_layout.LINKS_VIDEO_ICON_FILENAME
+            #image_stream=assets.convert_to_png(filename=image_file)
+            #self.track_stream(image_stream)
+            #slide.create_image(image_file=image_stream).at(link_position).with_size(current_layout.LINKS_IMAGE_SIZE).with_href(player_url)
+
+            #x_delta,_=current_layout.LINKS_IMAGE_SIZE
+            #x,y=link_position
+            #link_position=(x+x_delta,y)
 
             links_added=True
+        left_table.append_empty_row()
+        left_table.append_row('Ссылки',pb)
+
         if not links_added:
             logger.warn('No links added to presentation')
 
